#[non_exhaustive]pub enum BridgeSubclass {
AciBridge1xN = 0,
}Expand description
Enum for all known subclasses of the ACI Bridges device class
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AciBridge1xN = 0
The 1xN ACI Bridge subclass
Implementations
Sourceimpl BridgeSubclass
impl BridgeSubclass
Sourcepub const fn id(&self) -> u16
pub const fn id(&self) -> u16
Returns the numeric id associated with the BridgeSubclass.
Sourcepub const fn from_id(id: u16) -> Option<Self>
pub const fn from_id(id: u16) -> Option<Self>
Returns the BridgeSubclass associated with the given id if it exists, or otherwise returns None.
Stability
A None result of this function should not be considered stable, as a new registration may cause a previous None result to return a value.
A Some result is guaranteed to remain stable permanently (including accross major versions)
Sourcepub const fn into_generic(self) -> SubclassId
pub const fn into_generic(self) -> SubclassId
Converts the BridgeSubclass into a SubclassId
Sourcepub const fn public_name(&self) -> &'static str
pub const fn public_name(&self) -> &'static str
Retrieves the public (display) name from the registration associated with this BridgeSubclass.
This requires the extened-info crate feature to be enabled.
Stability
As the public name of a registration may be amended, the return value of this function is not considered stable.
Sourcepub const fn specification(&self) -> &'static str
pub const fn specification(&self) -> &'static str
Retrieves the Uniform Resource Location of the Specification from the registration associated with this BridgeSubclass.
This requires the extened-info crate feature to be enabled.
Stability
As the Specification URL of a registration may be amended, the return value of this function is not considered stable.